@@ -47,7 +47,7 @@
 /* Define it to one of __bss_start, edata and _edata.  */
 #  define BSS_START_SYMBOL __bss_start
 /* Define it to either end or _end.  */
-#  define END_SYMBOL _end
+#  define END_SYMBOL end
 /* Name of package.  */
 #  define PACKAGE "grub"
 /* Version number of package.  */
